@@ -698,7 +698,7 @@ FleetEventTypeType = Literal["fleet-change", "instance-change", "service-error"]
 FleetExcessCapacityTerminationPolicyType = Literal["no-termination", "termination"]
 FleetInstanceMatchCriteriaType = Literal["open"]
 FleetOnDemandAllocationStrategyType = Literal["lowest-price", "prioritized"]
-FleetReplacementStrategyType = Literal["launch"]
+FleetReplacementStrategyType = Literal["launch", "launch-before-terminate"]
 FleetStateCodeType = Literal[
     "active",
     "deleted",
@@ -1304,7 +1304,7 @@ RecurringChargeFrequencyType = Literal["Hourly"]
 ReplaceRootVolumeTaskStateType = Literal[
     "failed", "failed-detached", "failing", "in-progress", "pending", "succeeded"
 ]
-ReplacementStrategyType = Literal["launch"]
+ReplacementStrategyType = Literal["launch", "launch-before-terminate"]
 ReportInstanceReasonCodesType = Literal[
     "instance-stuck-in-state",
     "not-accepting-credentials",
@@ -1571,6 +1571,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
